package com.competition.adapter.app;

import com.competition.IAdapter;
import com.competition.adapter.BaseAdapter;
import com.competition.bean.DcFootSchedule;
import com.competition.constant.Constants;
import com.competition.service.IDcFootEuropeoddsService;
import com.competition.service.IDcFootScheduleService;
import com.competition.service.IDcLotteryMatchService;
import com.competition.utils.SpringUtils;
import com.competition.utils.Utils;
import com.competition.utils.xml.parse.ByteCodeUtil;
import com.competition.utils.xml.parse.XmlBean;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import org.springframework.stereotype.Component;

@Component
public class App0045Adapter extends BaseAdapter implements IAdapter {

   @Resource
   private IDcFootScheduleService scheduleService;
   @Resource
   private IDcLotteryMatchService lotteryMatchService;
   @Resource
   private IDcFootEuropeoddsService dcFootEuropeoddsService;
   private Long[] companyIds = new Long[]{Long.valueOf(115L), Long.valueOf(82L), Long.valueOf(281L), Long.valueOf(545L), Long.valueOf(90L), Long.valueOf(81L)};
   private double offset = 0.05D;


   public XmlBean execute(XmlBean xmlBean) {
      XmlBean requestBean = xmlBean.getFirst("request");
      XmlBean queryBean = requestBean.getFirst("query");
      Long scheduleId = Utils.formatLong(queryBean.attribute("scheduleId"));
      Long companyId = Long.valueOf(Utils.formatLong(queryBean.attribute("companyId"), 115));
      int page = Utils.formatInt(queryBean.attribute("page"), 1);
      int pageSize = Utils.formatInt(queryBean.attribute("pageSize"), Constants.PAGE_SIZE_10).intValue();
      if(scheduleId != null && companyId != null) {
         if(pageSize > Constants.PAGE_SIZE_50.intValue()) {
            pageSize = Constants.PAGE_SIZE_50.intValue();
         }

         try {
            DcFootSchedule e = this.scheduleService.getDcFootSchedule(scheduleId);
            if(e == null) {
               return this.returnErrorCodeBody("9000");
            } else {
               ArrayList maps = new ArrayList();
               Map map = this.lotteryMatchService.getFBAvgEuroOddsByScheduleIds(scheduleId.longValue(), this.companyIds);
               byte count = 0;
               if(((BigDecimal)map.get("win")).compareTo(BigDecimal.ZERO) == 1) {
                  double win = ((BigDecimal)map.get("win")).doubleValue();
                  double draw = ((BigDecimal)map.get("draw")).doubleValue();
                  double var16 = ((BigDecimal)map.get("lose")).doubleValue();
               }

               return this.buildXmlBean(map, maps, count);
            }
         } catch (Exception var18) {
            var18.printStackTrace();
            return this.returnErrorCodeBody("0999");
         }
      } else {
         return this.returnErrorCodeBody("0003");
      }
   }

   private XmlBean buildXmlBean(Map map, List maps, int count) {
      StringBuffer buffer = new StringBuffer();
      buffer.append("<body>");
      buffer.append("<list>");
      DecimalFormat df = new DecimalFormat("0.00");
      buffer.append("<victoryRate>");
      buffer.append(df.format((BigDecimal)map.get("ur")));
      buffer.append("</victoryRate>");
      buffer.append("<drawRate>");
      buffer.append(df.format((BigDecimal)map.get("gr")));
      buffer.append("</drawRate>");
      buffer.append("<loseRate>");
      buffer.append(df.format((BigDecimal)map.get("dr")));
      buffer.append("</loseRate>");
      buffer.append("<count>");
      buffer.append(count);
      buffer.append("</count>");
      if(maps != null && maps.size() > 0) {
         Iterator var7 = maps.iterator();

         while(var7.hasNext()) {
            Map m = (Map)var7.next();
            buffer.append("<match");
            buffer.append(" sclassId = \"" + m.get("sclass_id") + "\"");
            buffer.append(" sclass = \"" + m.get("name_js") + "\"");
            buffer.append(" beginTime = \"" + Utils.formatDate2Str((Date)m.get("match_time"), "yyyy-MM-dd hh:mm:ss") + "\"");
            buffer.append(" scheduleId = \"" + m.get("schedule_id") + "\"");
            buffer.append(" hostName = \"" + m.get("home_team") + "\"");
            buffer.append(" guestName = \"" + m.get("guest_team") + "\"");
            buffer.append(" hostScore = \"" + m.get("home_score") + "\"");
            buffer.append(" guestscore = \"" + m.get("guest_score") + "\"");
            buffer.append("/>");
         }

         if(maps.size() == 1) {
            buffer.append("<match/>");
         }
      } else {
         buffer.append("<match/>");
      }

      buffer.append("</list>");
      buffer.append("</body>");
      return ByteCodeUtil.xmlToObject(buffer.toString());
   }

   public static void main(String[] args) {
      String string = "<root><request><query scheduleId=\"1543297\" issue=\"20180505\" sn=\"030\"></query></request></root>";
      IAdapter adapter = (IAdapter)SpringUtils.getBean("app0045Adapter");
      System.out.println(adapter.execute(ByteCodeUtil.xmlToObject(string)).toString());
   }
}
